# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# Command to remove previously published entities
class SceneEntityDeletion(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = SceneEntityDeletion()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsSceneEntityDeletion(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # SceneEntityDeletion
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Timestamp of the deletion. Only matching entities earlier than this timestamp will be deleted.
    # SceneEntityDeletion
    def Timestamp(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = o + self._tab.Pos
            from .Time import Time
            obj = Time()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Type of deletion action to perform
    # SceneEntityDeletion
    def Type(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Uint8Flags, o + self._tab.Pos)
        return 0

    # Identifier which must match if `type` is `MATCHING_ID`.
    # SceneEntityDeletion
    def Id(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

def SceneEntityDeletionStart(builder): builder.StartObject(3)
def Start(builder):
    return SceneEntityDeletionStart(builder)
def SceneEntityDeletionAddTimestamp(builder, timestamp): builder.PrependStructSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(timestamp), 0)
def AddTimestamp(builder, timestamp):
    return SceneEntityDeletionAddTimestamp(builder, timestamp)
def SceneEntityDeletionAddType(builder, type): builder.PrependUint8Slot(1, type, 0)
def AddType(builder, type):
    return SceneEntityDeletionAddType(builder, type)
def SceneEntityDeletionAddId(builder, id): builder.PrependUOffsetTRelativeSlot(2, flatbuffers.number_types.UOffsetTFlags.py_type(id), 0)
def AddId(builder, id):
    return SceneEntityDeletionAddId(builder, id)
def SceneEntityDeletionEnd(builder): return builder.EndObject()
def End(builder):
    return SceneEntityDeletionEnd(builder)


# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

# Log level
class LogLevel(object):
    UNKNOWN = 0
    DEBUG = 1
    INFO = 2
    WARNING = 3
    ERROR = 4
    FATAL = 5



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

# An enumeration indicating how input points should be interpreted to create lines
class LineType(object):
    # Connected line segments: 0-1, 1-2, ..., (n-1)-n
    LINE_STRIP = 0
    # Closed polygon: 0-1, 1-2, ..., (n-1)-n, n-0
    LINE_LOOP = 1
    # Individual line segments: 0-1, 2-3, 4-5, ...
    LINE_LIST = 2



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# GeoJSON data for annotating maps
class GeoJSON(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = GeoJSON()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsGeoJSON(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # GeoJSON
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # GeoJSON data encoded as a UTF-8 string
    # GeoJSON
    def Geojson(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

def GeoJSONStart(builder): builder.StartObject(1)
def Start(builder):
    return GeoJSONStart(builder)
def GeoJSONAddGeojson(builder, geojson): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(geojson), 0)
def AddGeojson(builder, geojson):
    return GeoJSONAddGeojson(builder, geojson)
def GeoJSONEnd(builder): return builder.EndObject()
def End(builder):
    return GeoJSONEnd(builder)


# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# A navigation satellite fix for any Global Navigation Satellite System
class LocationFix(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = LocationFix()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsLocationFix(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # LocationFix
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Timestamp of the message
    # LocationFix
    def Timestamp(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = o + self._tab.Pos
            from .Time import Time
            obj = Time()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Frame for the sensor. Latitude and longitude readings are at the origin of the frame.
    # LocationFix
    def FrameId(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # Latitude in degrees
    # LocationFix
    def Latitude(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float64Flags, o + self._tab.Pos)
        return 0.0

    # Longitude in degrees
    # LocationFix
    def Longitude(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float64Flags, o + self._tab.Pos)
        return 0.0

    # Altitude in meters
    # LocationFix
    def Altitude(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float64Flags, o + self._tab.Pos)
        return 0.0

    # Position covariance (m^2) defined relative to a tangential plane through the reported position. The components are East, North, and Up (ENU), in row-major order.
    # length 9
    # LocationFix
    def PositionCovariance(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Float64Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 8))
        return 0

    # LocationFix
    def PositionCovarianceAsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Float64Flags, o)
        return 0

    # LocationFix
    def PositionCovarianceLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # LocationFix
    def PositionCovarianceIsNone(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        return o == 0

    # If `position_covariance` is available, `position_covariance_type` must be set to indicate the type of covariance.
    # LocationFix
    def PositionCovarianceType(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Uint8Flags, o + self._tab.Pos)
        return 0

def LocationFixStart(builder): builder.StartObject(7)
def Start(builder):
    return LocationFixStart(builder)
def LocationFixAddTimestamp(builder, timestamp): builder.PrependStructSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(timestamp), 0)
def AddTimestamp(builder, timestamp):
    return LocationFixAddTimestamp(builder, timestamp)
def LocationFixAddFrameId(builder, frameId): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(frameId), 0)
def AddFrameId(builder, frameId):
    return LocationFixAddFrameId(builder, frameId)
def LocationFixAddLatitude(builder, latitude): builder.PrependFloat64Slot(2, latitude, 0.0)
def AddLatitude(builder, latitude):
    return LocationFixAddLatitude(builder, latitude)
def LocationFixAddLongitude(builder, longitude): builder.PrependFloat64Slot(3, longitude, 0.0)
def AddLongitude(builder, longitude):
    return LocationFixAddLongitude(builder, longitude)
def LocationFixAddAltitude(builder, altitude): builder.PrependFloat64Slot(4, altitude, 0.0)
def AddAltitude(builder, altitude):
    return LocationFixAddAltitude(builder, altitude)
def LocationFixAddPositionCovariance(builder, positionCovariance): builder.PrependUOffsetTRelativeSlot(5, flatbuffers.number_types.UOffsetTFlags.py_type(positionCovariance), 0)
def AddPositionCovariance(builder, positionCovariance):
    return LocationFixAddPositionCovariance(builder, positionCovariance)
def LocationFixStartPositionCovarianceVector(builder, numElems): return builder.StartVector(8, numElems, 8)
def StartPositionCovarianceVector(builder, numElems):
    return LocationFixStartPositionCovarianceVector(builder, numElems)
def LocationFixAddPositionCovarianceType(builder, positionCovarianceType): builder.PrependUint8Slot(6, positionCovarianceType, 0)
def AddPositionCovarianceType(builder, positionCovarianceType):
    return LocationFixAddPositionCovarianceType(builder, positionCovarianceType)
def LocationFixEnd(builder): return builder.EndObject()
def End(builder):
    return LocationFixEnd(builder)


# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# A timestamped pose for an object or reference frame in 3D space
class PoseInFrame(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = PoseInFrame()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsPoseInFrame(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # PoseInFrame
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Timestamp of pose
    # PoseInFrame
    def Timestamp(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = o + self._tab.Pos
            from .Time import Time
            obj = Time()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Frame of reference for pose position and orientation
    # PoseInFrame
    def FrameId(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # Pose in 3D space
    # PoseInFrame
    def Pose(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Pose import Pose
            obj = Pose()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

def PoseInFrameStart(builder): builder.StartObject(3)
def Start(builder):
    return PoseInFrameStart(builder)
def PoseInFrameAddTimestamp(builder, timestamp): builder.PrependStructSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(timestamp), 0)
def AddTimestamp(builder, timestamp):
    return PoseInFrameAddTimestamp(builder, timestamp)
def PoseInFrameAddFrameId(builder, frameId): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(frameId), 0)
def AddFrameId(builder, frameId):
    return PoseInFrameAddFrameId(builder, frameId)
def PoseInFrameAddPose(builder, pose): builder.PrependUOffsetTRelativeSlot(2, flatbuffers.number_types.UOffsetTFlags.py_type(pose), 0)
def AddPose(builder, pose):
    return PoseInFrameAddPose(builder, pose)
def PoseInFrameEnd(builder): return builder.EndObject()
def End(builder):
    return PoseInFrameEnd(builder)


# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# A primitive representing a sphere or ellipsoid
class SpherePrimitive(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = SpherePrimitive()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsSpherePrimitive(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # SpherePrimitive
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Position of the center of the sphere and orientation of the sphere
    # SpherePrimitive
    def Pose(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Pose import Pose
            obj = Pose()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Size (diameter) of the sphere along each axis
    # SpherePrimitive
    def Size(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Vector3 import Vector3
            obj = Vector3()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Color of the sphere
    # SpherePrimitive
    def Color(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Color import Color
            obj = Color()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

def SpherePrimitiveStart(builder): builder.StartObject(3)
def Start(builder):
    return SpherePrimitiveStart(builder)
def SpherePrimitiveAddPose(builder, pose): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(pose), 0)
def AddPose(builder, pose):
    return SpherePrimitiveAddPose(builder, pose)
def SpherePrimitiveAddSize(builder, size): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(size), 0)
def AddSize(builder, size):
    return SpherePrimitiveAddSize(builder, size)
def SpherePrimitiveAddColor(builder, color): builder.PrependUOffsetTRelativeSlot(2, flatbuffers.number_types.UOffsetTFlags.py_type(color), 0)
def AddColor(builder, color):
    return SpherePrimitiveAddColor(builder, color)
def SpherePrimitiveEnd(builder): return builder.EndObject()
def End(builder):
    return SpherePrimitiveEnd(builder)


# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

# Type of position covariance
class PositionCovarianceType(object):
    UNKNOWN = 0
    APPROXIMATED = 1
    DIAGONAL_KNOWN = 2
    KNOWN = 3



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# A primitive representing a 3D model file loaded from an external URL or embedded data
class ModelPrimitive(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = ModelPrimitive()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsModelPrimitive(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # ModelPrimitive
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Origin of model relative to reference frame
    # ModelPrimitive
    def Pose(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Pose import Pose
            obj = Pose()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Scale factor to apply to the model along each axis
    # ModelPrimitive
    def Scale(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Vector3 import Vector3
            obj = Vector3()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Solid color to use for the whole model if `override_color` is true.
    # ModelPrimitive
    def Color(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Color import Color
            obj = Color()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Whether to use the color specified in `color` instead of any materials embedded in the original model.
    # ModelPrimitive
    def OverrideColor(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return bool(self._tab.Get(flatbuffers.number_types.BoolFlags, o + self._tab.Pos))
        return False

    # URL pointing to model file. One of `url` or `data` should be provided.
    # ModelPrimitive
    def Url(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # [Media type](https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types) of embedded model (e.g. `model/gltf-binary`). Required if `data` is provided instead of `url`. Overrides the inferred media type if `url` is provided.
    # ModelPrimitive
    def MediaType(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # Embedded model. One of `url` or `data` should be provided. If `data` is provided, `media_type` must be set to indicate the type of the data.
    # ModelPrimitive
    def Data(self, j):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Uint8Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 1))
        return 0

    # ModelPrimitive
    def DataAsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Uint8Flags, o)
        return 0

    # ModelPrimitive
    def DataLength(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # ModelPrimitive
    def DataIsNone(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        return o == 0

def ModelPrimitiveStart(builder): builder.StartObject(7)
def Start(builder):
    return ModelPrimitiveStart(builder)
def ModelPrimitiveAddPose(builder, pose): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(pose), 0)
def AddPose(builder, pose):
    return ModelPrimitiveAddPose(builder, pose)
def ModelPrimitiveAddScale(builder, scale): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(scale), 0)
def AddScale(builder, scale):
    return ModelPrimitiveAddScale(builder, scale)
def ModelPrimitiveAddColor(builder, color): builder.PrependUOffsetTRelativeSlot(2, flatbuffers.number_types.UOffsetTFlags.py_type(color), 0)
def AddColor(builder, color):
    return ModelPrimitiveAddColor(builder, color)
def ModelPrimitiveAddOverrideColor(builder, overrideColor): builder.PrependBoolSlot(3, overrideColor, 0)
def AddOverrideColor(builder, overrideColor):
    return ModelPrimitiveAddOverrideColor(builder, overrideColor)
def ModelPrimitiveAddUrl(builder, url): builder.PrependUOffsetTRelativeSlot(4, flatbuffers.number_types.UOffsetTFlags.py_type(url), 0)
def AddUrl(builder, url):
    return ModelPrimitiveAddUrl(builder, url)
def ModelPrimitiveAddMediaType(builder, mediaType): builder.PrependUOffsetTRelativeSlot(5, flatbuffers.number_types.UOffsetTFlags.py_type(mediaType), 0)
def AddMediaType(builder, mediaType):
    return ModelPrimitiveAddMediaType(builder, mediaType)
def ModelPrimitiveAddData(builder, data): builder.PrependUOffsetTRelativeSlot(6, flatbuffers.number_types.UOffsetTFlags.py_type(data), 0)
def AddData(builder, data):
    return ModelPrimitiveAddData(builder, data)
def ModelPrimitiveStartDataVector(builder, numElems): return builder.StartVector(1, numElems, 1)
def StartDataVector(builder, numElems):
    return ModelPrimitiveStartDataVector(builder, numElems)
def ModelPrimitiveEnd(builder): return builder.EndObject()
def End(builder):
    return ModelPrimitiveEnd(builder)


# automatically generated by the FlatBuffers compiler, do not modify

# namespace: foxglove

import flatbuffers
from flatbuffers.compat import import_numpy
np = import_numpy()

# A primitive representing a cylinder, elliptic cylinder, or truncated cone
class CylinderPrimitive(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset=0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = CylinderPrimitive()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsCylinderPrimitive(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # CylinderPrimitive
    def Init(self, buf, pos):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Position of the center of the cylinder and orientation of the cylinder. The flat face(s) are perpendicular to the z-axis.
    # CylinderPrimitive
    def Pose(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Pose import Pose
            obj = Pose()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # Size of the cylinder's bounding box
    # CylinderPrimitive
    def Size(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Vector3 import Vector3
            obj = Vector3()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # 0-1, ratio of the diameter of the cylinder's bottom face (min z) to the bottom of the bounding box
    # CylinderPrimitive
    def BottomScale(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float64Flags, o + self._tab.Pos)
        return 0.0

    # 0-1, ratio of the diameter of the cylinder's top face (max z) to the top of the bounding box
    # CylinderPrimitive
    def TopScale(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float64Flags, o + self._tab.Pos)
        return 0.0

    # Color of the cylinder
    # CylinderPrimitive
    def Color(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            from .Color import Color
            obj = Color()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

def CylinderPrimitiveStart(builder): builder.StartObject(5)
def Start(builder):
    return CylinderPrimitiveStart(builder)
def CylinderPrimitiveAddPose(builder, pose): builder.PrependUOffsetTRelativeSlot(0, flatbuffers.number_types.UOffsetTFlags.py_type(pose), 0)
def AddPose(builder, pose):
    return CylinderPrimitiveAddPose(builder, pose)
def CylinderPrimitiveAddSize(builder, size): builder.PrependUOffsetTRelativeSlot(1, flatbuffers.number_types.UOffsetTFlags.py_type(size), 0)
def AddSize(builder, size):
    return CylinderPrimitiveAddSize(builder, size)
def CylinderPrimitiveAddBottomScale(builder, bottomScale): builder.PrependFloat64Slot(2, bottomScale, 0.0)
def AddBottomScale(builder, bottomScale):
    return CylinderPrimitiveAddBottomScale(builder, bottomScale)
def CylinderPrimitiveAddTopScale(builder, topScale): builder.PrependFloat64Slot(3, topScale, 0.0)
def AddTopScale(builder, topScale):
    return CylinderPrimitiveAddTopScale(builder, topScale)
def CylinderPrimitiveAddColor(builder, color): builder.PrependUOffsetTRelativeSlot(4, flatbuffers.number_types.UOffsetTFlags.py_type(color), 0)
def AddColor(builder, color):
    return CylinderPrimitiveAddColor(builder, color)
def CylinderPrimitiveEnd(builder): return builder.EndObject()
def End(builder):
    return CylinderPrimitiveEnd(builder)